package com.shzg.project.worn.service;

import java.util.List;
import com.shzg.project.worn.domain.WornDeclareBill;

/**
 * 申报单查看Service接口
 * 
 * @author shzg
 * @date 2026-04-14
 */
public interface IWornDeclareBillService 
{
    /**
     * 查询申报单查看
     * 
     * @param id 申报单查看主键
     * @return 申报单查看
     */
    public WornDeclareBill selectWornDeclareBillById(Long id);

    /**
     * 查询申报单查看列表
     * 
     * @param wornDeclareBill 申报单查看
     * @return 申报单查看集合
     */
    public List<WornDeclareBill> selectWornDeclareBillList(WornDeclareBill wornDeclareBill);

    /**
     * 新增申报单查看
     * 
     * @param wornDeclareBill 申报单查看
     * @return 结果
     */
    public int insertWornDeclareBill(WornDeclareBill wornDeclareBill);

    /**
     * 修改申报单查看
     * 
     * @param wornDeclareBill 申报单查看
     * @return 结果
     */
    public int updateWornDeclareBill(WornDeclareBill wornDeclareBill);

    /**
     * 批量删除申报单查看
     * 
     * @param ids 需要删除的申报单查看主键集合
     * @return 结果
     */
    public int deleteWornDeclareBillByIds(Long[] ids);

    /**
     * 删除申报单查看信息
     * 
     * @param id 申报单查看主键
     * @return 结果
     */
    public int deleteWornDeclareBillById(Long id);
    /**
     * 根据申报单号查询申报单详情
     *
     * @param billNo 申报单号
     * @return 申报单详情
     */
    WornDeclareBill selectWornDeclareBillDetailByBillNo(String billNo);
    /**
     * 作废申报单
     *
     * @param id 申报单ID
     * @return 结果
     */
    int cancelWornDeclareBill(Long id);
}
